@@ -1,5 +1,5 @@
 package Text::Hogan::Compiler;
-$Text::Hogan::Compiler::VERSION = '0.03';
+$Text::Hogan::Compiler::VERSION = '0.04';
 use Text::Hogan::Template;
 
 use strict;
@@ -519,13 +519,15 @@ my %cache;
 
 sub cache_key {
     my ($text, $options) = @_;
-    return join("||", $text, !!$options->{'as_string'}, !!$options->{'disable_lambda'}, ($options->{'delimiters'} // ""), !!$options->{'model_get'});
+    return join("||", $text, !!$options->{'as_string'}, !!$options->{'disable_lambda'}, ($options->{'delimiters'} || ""), !!$options->{'model_get'});
 }
 
 sub compile {
     my ($self, $text, $options) = @_;
     $options ||= {};
-    $text //= "";
+    if (!defined $text) {
+        $text = "";
+    }
     my $key = cache_key($text, $options);
     my $template = $cache{$key};
 
@@ -556,7 +558,7 @@ Text::Hogan::Compiler - parse templates and output Perl code
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
