@@ -1,5 +1,5 @@
 package Text::Hogan::Template;
-$Text::Hogan::Template::VERSION = '0.03';
+$Text::Hogan::Template::VERSION = '0.04';
 use strict;
 use warnings;
 
@@ -53,7 +53,7 @@ sub v {
 
 sub t {
     my ($self, $str) = @_;
-    return $str // "";
+    return defined($str) ? $str : "";
 }
 
 sub render {
@@ -395,7 +395,7 @@ sub create_specialized_partial {
 
 sub coerce_to_string {
     my ($str) = @_;
-    return $str // "";
+    return defined($str) ? $str : "";
 }
 
 1;
@@ -408,7 +408,7 @@ Text::Hogan::Template - represent and render compiled templates
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
